@@ -175,7 +175,10 @@ class NN():
                 Defaults to False.
         """
         # Used for tb naming.
-        self.loss = loss
+        if isinstance(loss, str):
+            self.loss = loss
+        else:
+            self.loss = "loss"
 
         if self.loss == "l1":
             self.loss_objective = tf.keras.losses.MeanAbsoluteError()
