@@ -18,4 +18,4 @@ from dnnlab.input_pipeline import img_img
 from dnnlab.input_pipeline import img_label
 from dnnlab.input_pipeline import yolo
 from dnnlab.input_pipeline.triplet_net import TripletDataset
-from dnnlab.input_pipeline.data_augmentation import YoloAugmentation
\ No newline at end of file
+from dnnlab.input_pipeline import augmentation
\ No newline at end of file
