@@ -27,6 +27,7 @@ def create_dataset(tfrecords,
                    keys,
                    encoding=True,
                    one_hot_labels=False,
+                   compression_type=None,
                    prefetching=True,
                    cache=True):
     """Creates an optimized tf.data.Dataset object from a tfrecords file.
@@ -44,6 +45,7 @@ def create_dataset(tfrecords,
         tfrecords file
     """
     raw_dataset = tf.data.TFRecordDataset(tfrecords,
+                                          compression_type,
                                           buffer_size=None,
                                           num_parallel_reads=num_parallel_reads)
 
